/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Dict
 *
 * The Initial Developer of the Original Code is David Costanzo
 * Portions created by the Initial Developer are Copyright (C) 2003-2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// dictInit will be called every time a new browser window is created
window.addEventListener("load", dictInit, false);

// Returns the selected text as a string.
function getSelection() 
{
    var selectedWord = gContextMenu.searchSelected();

    // sanitize the selection
    selectedWord = selectedWord.replace(/^\W+/, ''); // trim leading non-alnum chars
    selectedWord = selectedWord.replace(/\W+$/, ''); // trim trailing non-alnum chars
    selectedWord = selectedWord.replace(/\s+/, ' '); // conflate whitespace runs

    return selectedWord;
}

        
function defineSelection()
{
    var selectedWord = getSelection();

    if (selectedWord.indexOf('"') != -1) {
        alert("Sorry, selections that contain quotation marks cannot be defined.");
        return;
    }

    if (selectedWord.length == 0) {
        alert("Please select a word to define.");
        return;
    }

    try {
        var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);

        // read the host and port from the preferences
        var host;
        var port;

        try {
            host = pref.getCharPref('extensions.dict.defaultservername');
            port = pref.getIntPref('extensions.dict.defaultserverport');
        }
        catch (e) {
            // REVIST: 
            //   If there the preferences are not set/corrupt, should 
            //   we just use a reasonable default or should we warn the
            //   user.
            host = 'dict.org';
            port = 2628;
        }

        var client = new DictClient();
        client.defineWord(host, port, selectedWord);
    }
    catch (ex) {
        alert(ex);
    }
}


function dictInit() {

    var contextMenu = document.getElementById("contentAreaContextMenu");

    // The first time dictInit is called, contextMenu is null.
    // This test prevents an error from being logged in the JavaScript Console
    if (contextMenu != null) {
        contextMenu.addEventListener(
            "popupshowing",
            onDictPopup,
            false);  
    }
}


// hide the Dictionary Search item when apropriate (use same logic as for web search)
function onDictPopup() {

    var item = document.getElementById('dict-define-selection');
    if (gContextMenu.isTextSelected) {

        var selection = getSelection();
        
        const LENGTHCUTOFF = 15;

        if (LENGTHCUTOFF < selection.length) {
            // selection is too long to appear in menu.  It must be abbreviated.
            selection = selection.slice(0, LENGTHCUTOFF) + '...';
        }

        var dictStringBundle = document.getElementById("dict_string_bundle");
        var labelTemplate = dictStringBundle.getString("context_searchselect.label");

        item.setAttribute("label", labelTemplate.replace('%S', selection));
        item.hidden = false; // show the menu item
    }
    else {
        item.hidden = true; // hide the menu item
    }
}
